@@ -1,14 +1,14 @@
 package commit
 
 import (
-	pb "gitlab.com/gitlab-org/gitaly-proto/go"
+	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/git/catfile"
 	gitlog "gitlab.com/gitlab-org/gitaly/internal/git/log"
 )
 
 const batchSizeListCommitsByOid = 20
 
-func (s *server) ListCommitsByOid(in *pb.ListCommitsByOidRequest, stream pb.CommitService_ListCommitsByOidServer) error {
+func (s *server) ListCommitsByOid(in *gitalypb.ListCommitsByOidRequest, stream gitalypb.CommitService_ListCommitsByOidServer) error {
 	ctx := stream.Context()
 
 	c, err := catfile.New(ctx, in.Repository)
@@ -16,11 +16,11 @@ func (s *server) ListCommitsByOid(in *pb.ListCommitsByOidRequest, stream pb.Comm
 		return err
 	}
 
-	send := func(commits []*pb.GitCommit) error {
-		return stream.Send(&pb.ListCommitsByOidResponse{Commits: commits})
+	send := func(commits []*gitalypb.GitCommit) error {
+		return stream.Send(&gitalypb.ListCommitsByOidResponse{Commits: commits})
 	}
 
-	var commits []*pb.GitCommit
+	var commits []*gitalypb.GitCommit
 	for _, oid := range in.Oid {
 		commit, err := gitlog.GetCommitCatfile(c, oid)
 		if err != nil {
